@@ -1,6 +1,7 @@
 from datetime import datetime
 from io import StringIO
 
+import tzlocal
 from nonebot import on_command
 from nonebot.adapters.onebot.v11 import Bot, MessageEvent, GroupMessageEvent
 from nonebot.internal.matcher import Matcher
@@ -46,7 +47,7 @@ async def export_season_games(bot: Bot, event: MessageEvent, matcher: Matcher):
     if season.state == SeasonState.finished:
         filename += "（已结束）"
     else:
-        now = datetime.now()
+        now = datetime.now(tzlocal.get_localzone())
         filename += f"（截至{encode_date(now)}）"
     filename += ".csv"
 
@@ -72,7 +73,7 @@ async def export_group_games(bot: Bot, event: MessageEvent, matcher: Matcher):
     group = await get_group_by_binding_qq(matcher.state["binding_qq"])
     games = await get_group_games(group)
 
-    now = datetime.now()
+    now = datetime.now(tzlocal.get_localzone())
     filename = f"所有对局（截至{encode_date(now)}）.csv"
 
     with StringIO() as sio:
